package VMOMI::CustomizationLicenseDataMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
